==> knative-model-4.12.0-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeStatusBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeStatusBuilder extends EventTypeStatusFluentImpl<EventTypeStatusBuilder> implements VisitableBuilder<EventTypeStatus,EventTypeStatusBuilder> {

    EventTypeStatusFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeStatusBuilder() { 
        this(true);
    }


    public EventTypeStatusBuilder(Boolean validationEnabled) { 
        this(new EventTypeStatus(), validationEnabled);
    }


    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new EventTypeStatus(), validationEnabled);
    }


    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,EventTypeStatus instance) { 
        this(fluent, instance, true);
    }


    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,EventTypeStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventTypeStatusBuilder(EventTypeStatus instance) { 
        this(instance,true);
    }


    public EventTypeStatusBuilder(EventTypeStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventTypeStatus build() {
        EventTypeStatus buildable = new EventTypeStatus(fluent.getAnnotations(),fluent.getConditions(),fluent.getObservedGeneration());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeStatusBuilder that = (EventTypeStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeStatusBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeStatusBuilder extends EventTypeStatusFluentImpl<EventTypeStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<EventTypeStatus,EventTypeStatusBuilder> {

    EventTypeStatusFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeStatusBuilder() {
        this(true);
    }

    public EventTypeStatusBuilder(Boolean validationEnabled) {
        this(new EventTypeStatus(), validationEnabled);
    }

    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EventTypeStatus(), validationEnabled);
    }

    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,EventTypeStatus instance) {
        this(fluent, instance, true);
    }

    public EventTypeStatusBuilder(EventTypeStatusFluent<?> fluent,EventTypeStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventTypeStatusBuilder(EventTypeStatus instance) {
        this(instance,true);
    }

    public EventTypeStatusBuilder(EventTypeStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1beta1.EditableEventTypeStatus build() {
        EditableEventTypeStatus buildable = new EditableEventTypeStatus(fluent.getAnnotations(),fluent.getConditions(),fluent.getObservedGeneration());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeStatusBuilder that = (EventTypeStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
